Usage
-----
Converting numerals from roman to arabic:

.. code-block:: python
    
    >>> import romanify
    >>> romanify.roman2arabic("MMXV")
    2015
    
    
From arabic to roman:

.. code-block:: python

    >>> import romanify
    >>> romanify.arabic2roman(2015)
    "MMXV"
